@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bvideodvdjob.h,v 1.2.2.1 2004/02/07 17:56:56 trueg Exp $
+ * $Id: k3bvideodvdjob.h 325367 2004-07-02 16:15:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -24,21 +24,20 @@ class K3bVideoDvdDoc;
 
 /**
  * This class heavily depends on K3bDvdJob and uses some of it's internals.
- * This is bad design but makes this classes code very small.
  */
 class K3bVideoDvdJob : public K3bDvdJob
 {
   Q_OBJECT
 
  public:
-  K3bVideoDvdJob( K3bVideoDvdDoc*, QObject* parent = 0 );
+  K3bVideoDvdJob( K3bVideoDvdDoc*, K3bJobHandler*, QObject* parent = 0 );
   virtual ~K3bVideoDvdJob();
 
   virtual QString jobDescription() const;
   virtual QString jobDetails() const;
 
- public slots:
-  void start();
+/*  public slots: */
+/*   void start(); */
 
  private:
   void prepareIsoImager();
